@@ -18,24 +18,22 @@
 #include	<fcntl.h>
 #include	<ctype.h>
 #include	"numlib/numlib.h"
-#include	"liblock/config.h"
 #include	"liblock/liblock.h"
 #include	"auth.h"
 #include	"authdaemonrc.h"
 #include	"courierauthdebug.h"
 #include	"pkglibdir.h"
-#include	"authstaticlist.h"
+#include	"courierauthstaticlist.h"
 #include        "libhmac/hmac.h"
 #include        "cramlib.h"
 #include	<ltdl.h>
 
-static const char rcsid[]="$Id: authdaemond.c,v 1.35 2009/06/27 15:51:48 mrsam Exp $";
 
 #ifndef	SOMAXCONN
 #define	SOMAXCONN	5
 #endif
 
-#include	"authstaticlist.h"
+#include	"courierauthstaticlist.h"
 
 static unsigned ndaemons;
 
