@@ -4,13 +4,12 @@
 */
 
 #include	"auth.h"
-#include	"authstaticlist.h"
+#include	"courierauthstaticlist.h"
 #include	"courierauthsasl.h"
 #include	<stdlib.h>
 #include	<stdio.h>
 #include	<string.h>
 
-static const char rcsid[]="$Id: preauthdaemon.c,v 1.2 2004/10/21 00:10:49 mrsam Exp $";
 
 extern int authdaemondo(const char *authreq,
 	int (*func)(struct authinfo *, void *), void *arg);
